==> dde-shell_1.99.32.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="159"/>
        <source>Indicator Style</source>
        <translation>Стиль індикатора</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="161"/>
        <source>Fashion Mode</source>
        <translation>Модний режим</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="166"/>
        <source>Efficient Mode</source>
        <translation>Практичний режим</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="203"/>
        <source>Left</source>
        <translation>Ліворуч</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="191"/>
        <source>Position</source>
        <translation>Розташування</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="172"/>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="176"/>
        <source>Align Left</source>
        <translation>Вирівняти ліворуч</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="178"/>
        <source>Align Top</source>
        <translation>Вирівняти вгору</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="185"/>
        <source>Align Center</source>
        <translation>Вирівняти за центром</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="193"/>
        <source>Top</source>
        <translation>Вгорі</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="198"/>
        <source>Bottom</source>
        <translation>Внизу</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="208"/>
        <source>Right</source>
        <translation>Праворуч</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="214"/>
        <source>Status</source>
        <translation>Стан</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="216"/>
        <source>Keep Shown</source>
        <translation>Показувати постійно</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="221"/>
        <source>Keep Hidden</source>
        <translation>Приховувати</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="226"/>
        <source>Smart Hide</source>
        <translation>Розумне приховування</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="233"/>
        <source>Dock Settings</source>
        <translation>Параметри бічної панелі</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.37.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Стиль індикатора</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Модний режим</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Практичний режим</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Класичний режим</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Центрований режим</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Ліворуч</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Розташування</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Вгорі</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Внизу</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Праворуч</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Стан</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Показувати постійно</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Приховувати</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Розумне приховування</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Параметри бічної панелі</translation>
    </message>
</context>
</TS>
